Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1359)

Unified Diff: content/public/browser/notification_event_dispatcher.h

Issue 2300093002: Make //content responsible for generating notification Ids (Closed)
Patch Set: comments Created 4 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/public/browser/notification_event_dispatcher.h
diff --git a/content/public/browser/notification_event_dispatcher.h b/content/public/browser/notification_event_dispatcher.h
index 9cc43d4017c8a5163b203d7439e73498529fe4aa..1c2289d3ffc9c5820d025eab48d41f69100a3730 100644
--- a/content/public/browser/notification_event_dispatcher.h
+++ b/content/public/browser/notification_event_dispatcher.h
@@ -5,7 +5,6 @@
#ifndef CONTENT_PUBLIC_BROWSER_NOTIFICATION_EVENT_DISPATCHER_H_
#define CONTENT_PUBLIC_BROWSER_NOTIFICATION_EVENT_DISPATCHER_H_
-#include <stdint.h>
#include <string>
#include "base/callback_forward.h"
@@ -17,7 +16,6 @@ class GURL;
namespace content {
class BrowserContext;
-struct PlatformNotificationData;
// This is the dispatcher to be used for firing events related to persistent
// notifications on a Service Worker. This class is a singleton, the instance of
@@ -31,23 +29,23 @@ class CONTENT_EXPORT NotificationEventDispatcher {
base::Callback<void(PersistentNotificationStatus)>;
// Dispatches the "notificationclick" event on the Service Worker associated
// with |persistent_notification_id| belonging to |origin|. The |callback|
// will be invoked when it's known whether the event successfully executed.
virtual void DispatchNotificationClickEvent(
BrowserContext* browser_context,
- int64_t persistent_notification_id,
+ const std::string& notification_id,
const GURL& origin,
int action_index,
const NotificationDispatchCompleteCallback&
dispatch_complete_callback) = 0;
// Dispatches the "notificationclose" event on the Service Worker associated
// with |persistent_notification_id| belonging to |origin|. The
// |dispatch_complete_callback| will be invoked when it's known whether the
// event successfully executed.
virtual void DispatchNotificationCloseEvent(
BrowserContext* browser_context,
- int64_t persistent_notification_id,
+ const std::string& notification_id,
const GURL& origin,
bool by_user,
const NotificationDispatchCompleteCallback&
@@ -31,23 +29,23 @@ class CONTENT_EXPORT NotificationEventDispatcher {
base::Callback<void(PersistentNotificationStatus)>;
// Dispatches the "notificationclick" event on the Service Worker associated
- // with |persistent_notification_id| belonging to |origin|. The |callback|
- // will be invoked when it's known whether the event successfully executed.
+ // with |notification_id| belonging to |origin|. The |callback| will be
+ // invoked when it's known whether the event successfully executed.
virtual void DispatchNotificationClickEvent(
BrowserContext* browser_context,
@@ -31,23 +29,23 @@ class CONTENT_EXPORT NotificationEventDispatcher {
dispatch_complete_callback) = 0;
// Dispatches the "notificationclose" event on the Service Worker associated
- // with |persistent_notification_id| belonging to |origin|. The
+ // with |notification_id| belonging to |origin|. The
// |dispatch_complete_callback| will be invoked when it's known whether the
// event successfully executed.
« no previous file with comments | « content/public/browser/notification_database_data.cc ('k') | content/public/browser/platform_notification_context.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698